function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

function _inheritsLoose(subClass, superClass) { subClass.prototype = Object.create(superClass.prototype); subClass.prototype.constructor = subClass; subClass.__proto__ = superClass; }

/** @component input */
import React from 'react';
import PropTypes from 'prop-types';
import omit from 'lodash/omit';
import { Icon, InputError, InputHelper, Label } from "./..";

var determineErrorType = function determineErrorType(array) {
  return array.reduce(function (agg, e) {
    return agg === 'error' ? agg : e.type || '';
  }, '');
};

var filterErrorsByType = function filterErrorsByType(array, value) {
  return array.reduce(function (agg, e) {
    return e.type === value ? agg.concat(e.error) : agg;
  }, []);
};
/** Text input with integrated label to enforce consistency in layout, error display, label placement, and required field marker. */


var Input =
/*#__PURE__*/
function (_React$Component) {
  _inheritsLoose(Input, _React$Component);

  function Input() {
    var _this;

    for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    _this = _React$Component.call.apply(_React$Component, [this].concat(args)) || this;
    _this.state = {
      isEditing: false,
      value: _this.props.value || _this.props.defaultValue
    };

    _this.setValue = function (value) {
      _this.setState({
        value: value
      });
    };

    _this.handleKeyDown = function (e) {
      var onKeyDown = _this.props.onKeyDown;
      onKeyDown && onKeyDown(e);
    };

    _this.handleFocus = function (e) {
      var _this$props = _this.props,
          onFocus = _this$props.onFocus,
          disabled = _this$props.disabled;

      if (disabled) {
        e.stopPropagation();
        return;
      }

      if (onFocus) {
        onFocus(e);
      }

      _this.setState({
        isEditing: true
      });
    };

    _this.handleMouseDown = function (e) {
      var _this$props2 = _this.props,
          onMouseDown = _this$props2.onMouseDown,
          disabled = _this$props2.disabled;

      if (disabled) {
        e.stopPropagation();
        return;
      }

      if (onMouseDown) {
        onMouseDown(e);
      }

      _this.setState({
        isEditing: true
      });
    };

    _this.handleChange = function (e) {
      var onChange = _this.props.onChange;
      var value = e.target.value;
      e.persist();

      _this.setState(function () {
        onChange && onChange(e);
        return {
          value: value
        };
      });
    };

    _this.handleBlur = function (e) {
      var onDoneEditing = _this.props.onDoneEditing;
      var value = e.target.value;
      e.stopPropagation();

      if (e.keyCode === 27 || e.keyCode === 13 || e.type === 'blur') {
        _this.setState({
          isEditing: false
        }, function () {
          return onDoneEditing && onDoneEditing(e, value);
        });
      }
    };

    _this.handleClear = function (e) {
      var value = '';
      e.target.value = value;
      e.persist();

      _this.input.focus();

      _this.handleChange(e);
    };

    _this.setInputRef = function (input) {
      var _this$props3 = _this.props,
          clear = _this$props3.clear,
          inputRef = _this$props3.inputRef;
      if (clear) _this.input = input;
      if (inputRef) return inputRef(input);
    };

    return _this;
  }

  var _proto = Input.prototype;

  _proto.componentDidUpdate = function componentDidUpdate(prevProps) {
    var value = this.props.value;
    value !== prevProps.value && this.setValue(value);
  };

  _proto.render = function render() {
    var _this$props4 = this.props,
        children = _this$props4.children,
        className = _this$props4.className,
        clear = _this$props4.clear,
        clearAriaLabel = _this$props4.clearAriaLabel,
        disabled = _this$props4.disabled,
        errorArr = _this$props4.errorArr,
        htmlId = _this$props4.htmlId,
        iconNode = _this$props4.iconNode,
        id = _this$props4.id,
        inputClassName = _this$props4.inputClassName,
        inputHelpText = _this$props4.inputHelpText,
        inputSize = _this$props4.inputSize,
        label = _this$props4.label,
        nestedLevel = _this$props4.nestedLevel,
        placeholder = _this$props4.placeholder,
        readOnly = _this$props4.readOnly,
        secondaryLabel = _this$props4.secondaryLabel,
        theme = _this$props4.theme,
        type = _this$props4.type,
        props = _objectWithoutPropertiesLoose(_this$props4, ["children", "className", "clear", "clearAriaLabel", "disabled", "errorArr", "htmlId", "iconNode", "id", "inputClassName", "inputHelpText", "inputSize", "label", "nestedLevel", "placeholder", "readOnly", "secondaryLabel", "theme", "type"]);

    var value = this.state.value;
    var otherProps = omit(_extends({}, props), ['defaultValue', 'inputRef', 'onChange', 'onDoneEditing', 'onFocus', 'onKeyDown', 'onMouseDown', 'ref', 'value']);
    var errorType = errorArr.length > 0 && determineErrorType(errorArr) || '';
    var errors = errorType && filterErrorsByType(errorArr, errorType) || [];

    var secondaryLabelWrapper = function secondaryLabelWrapper() {
      return React.createElement("div", {
        className: "cui-label__secondary-label-container"
      }, inputElement, React.createElement(Label, {
        className: "cui-label__secondary-label",
        htmlFor: htmlId,
        label: secondaryLabel,
        theme: theme
      }));
    };

    var clearButton = clear && !disabled && value && React.createElement(Icon, {
      name: "clear-active_16",
      onClick: this.handleClear,
      ariaLabel: clearAriaLabel || 'clear input',
      className: "cui-input__icon-clear"
    });

    var iconContainer = function iconContainer() {
      return React.createElement("div", {
        className: "cui-input__icon-container"
      }, inputElement, children, iconNode || clearButton);
    };

    var inputElement = React.createElement("input", _extends({
      className: 'cui-input' + ("" + (inputClassName ? " " + inputClassName : '')) + ("" + (readOnly ? ' read-only' : '')) + ("" + (disabled ? ' disabled' : '')) + ("" + (value ? " dirty" : '')),
      onBlur: this.handleBlur,
      onChange: this.handleChange,
      onFocus: this.handleFocus,
      onKeyDown: this.handleKeyDown,
      onMouseDown: this.handleMouseDown,
      ref: this.setInputRef,
      tabIndex: 0,
      type: type,
      value: value
    }, disabled && {
      disabled: disabled
    }, htmlId && {
      id: htmlId
    }, otherProps, placeholder && {
      placeholder: placeholder
    }, readOnly && {
      readOnly: readOnly
    }));

    var getInputWrapper = function getInputWrapper() {
      if (iconNode || clear || children) return iconContainer();
      if (secondaryLabel) return secondaryLabelWrapper();
      return inputElement;
    };

    return React.createElement("div", {
      className: "cui-input-group" + (" " + inputSize) + ("" + (inputSize ? ' columns' : '')) + ("" + (readOnly ? ' read-only' : '')) + ("" + (disabled ? ' disabled' : '')) + ("" + (theme && " cui-input-group--" + theme || '')) + ("" + (errorType ? " " + errorType : '')) + ("" + (nestedLevel && " cui-input--nested-" + nestedLevel || '')) + ("" + (className ? " " + className : ''))
    }, label && React.createElement(Label, {
      className: "cui-label",
      htmlFor: htmlId || id,
      label: label,
      theme: theme
    }), getInputWrapper(), inputHelpText && React.createElement(InputHelper, {
      message: inputHelpText
    }), errors && errors.map(function (e, i) {
      return React.createElement(InputError, {
        error: e,
        key: "input-error-" + i
      });
    }));
  };

  return Input;
}(React.Component);

Input.propTypes = {
  /** @prop Child component to display next to the input | '' */
  children: PropTypes.node,

  /** @prop Optional css class name | '' */
  className: PropTypes.string,

  /** @prop Clears Input values | false */
  clear: PropTypes.bool,

  /** @prop Optional aria label on the clear button | null */
  clearAriaLabel: PropTypes.string,

  /** @prop Default Value same as value but used when onChange isn't invoked | '' */
  defaultValue: PropTypes.oneOfType([PropTypes.string, PropTypes.number]),

  /*** @prop Sets the disabled attribute of the Input | false */
  disabled: PropTypes.bool,

  /** @prop Array of Objects with error and type [{error: '', type: ''}] to display error message and assign class | [] */
  errorArr: PropTypes.array,

  /** @prop Unique HTML ID used for tying label to HTML input for automated testing | null */
  htmlId: PropTypes.string,

  /** Optional Icon node that overrides the default clear icon | null */
  iconNode: PropTypes.node,

  /** Unique HTML ID used for tying label to HTML input | null */
  id: PropTypes.string,

  /** @prop Input css class name string | '' */
  inputClassName: PropTypes.string,

  /** @prop Help Text to show form validation rules | '' */
  inputHelpText: PropTypes.string,

  /*** @prop Optional Input ref prop type | null */
  inputRef: PropTypes.func,

  /** @prop Overall input group size | '' */
  inputSize: PropTypes.string,

  /** @prop Input label text | '' */
  label: PropTypes.string,

  /*** @prop Optional Input name prop type | null */
  name: PropTypes.string,

  /** @prop Set the level of nested Input components | 0 */
  nestedLevel: PropTypes.number,

  /** @prop Callback function invoked when user types into the Input field | null */
  onChange: PropTypes.func,

  /*** @prop Callback function invoked when user is done editing Input field | null */
  onDoneEditing: PropTypes.func,

  /*** @prop Callback function invoked when user focuses on the Input field | null */
  onFocus: PropTypes.func,

  /*** @prop Callback function invoked when user presses any key | null */
  onKeyDown: PropTypes.func,

  /*** @prop Callback function invoked when user clicks on the mouse/trackpad | null */
  onMouseDown: PropTypes.func,

  /** @prop Placeholder text to display when Input is empty | '' */
  placeholder: PropTypes.string,

  /*** @prop Determines if Input can be edited | false */
  readOnly: PropTypes.bool,

  /** @prop Secondary Input label | '' */
  secondaryLabel: PropTypes.string,

  /** @prop Input color theme | '' */
  theme: PropTypes.string,

  /** @prop Input type | 'text' */
  type: PropTypes.oneOf(['text', 'number', 'password', 'email']),

  /** @prop Input value | '' */
  value: PropTypes.oneOfType([PropTypes.string, PropTypes.number])
};
Input.defaultProps = {
  children: '',
  className: '',
  clear: false,
  clearAriaLabel: null,
  defaultValue: '',
  disabled: false,
  errorArr: [],
  htmlId: null,
  iconNode: null,
  id: null,
  inputClassName: '',
  inputHelpText: '',
  inputRef: null,
  inputSize: '',
  label: '',
  name: null,
  nestedLevel: 0,
  onChange: null,
  onDoneEditing: null,
  onFocus: null,
  onKeyDown: null,
  onMouseDown: null,
  placeholder: '',
  readOnly: false,
  secondaryLabel: '',
  theme: '',
  type: 'text',
  value: ''
};
Input.displayName = 'Input';
export default Input;
/**
* @component input
* @section default
* @react
import { Input } from '@collab-ui/react';

export default class InputDefault extends React.PureComponent {

  render() {
    return (
      <Input
        name='defaultInput'
        label='Default Input'
        htmlId='defaultInput'
        inputSize='small-5'
        placeholder='Placeholder Text'
      />
    );
  }
}

**/

/**
* @component input
* @section clear
* @react
import { Input } from '@collab-ui/react';

export default class InputClear extends React.PureComponent {
  state = {
    value: 'Press or click the clear icon to clear this input'
  };

  handleChange = (event) => {
    this.setState({value: event.target.value});
  }

  render() {
    return (
      <Input
        name='clearInput'
        label='Input with clear'
        htmlId='clearInput'
        inputSize='small-5'
        placeholder='Placeholder Text'
        value={this.state.value}
        onChange={this.handleChange}
        clear
      />
    );
  }
}

**/

/**
* @component input
* @section error
* @react
import { Input } from '@collab-ui/react';

export default function InputError() {
  return (
    <Input
      name='inputError'
      label='Error (Error) Input'
      htmlId='inputError'
      inputSize='small-5'
      errorArr={ [{error: 'This is where the error message would be.', type: 'error'}] }
    />
  );
}

**/

/**
* @component input
* @section warning
* @react
import { Input } from '@collab-ui/react';

export default function InputWarning() {
  return (
    <Input
      name='inputWarning'
      label='Error (Warning) Input'
      htmlId='inputWarning'
      inputSize='small-5'
      errorArr={ [{error: 'This is where the warning message would be.', type: 'warning'}] }
    />
  );
}

**/

/**
* @component input
* @section success
* @react
import { Input } from '@collab-ui/react';

export default function InputSuccess() {
  return (
    <Input
      name='inputSuccess'
      label='Error (Success) Input'
      htmlId='inputSuccess'
      inputSize='small-5'
      errorArr={ [{error: 'This is where the success message would be.', type: 'success'}] }
    />
  );
}

**/

/**
* @component input
* @section disabled
* @react
import { Input } from '@collab-ui/react';

export default function InputDisabled() {
  return (
    <Input
      name='inputDisabled'
      label='Disabled Input'
      htmlId='inputDisabled'
      inputSize='small-5'
      value='Disabled Text'
      disabled
    />
  );
}

**/

/**
* @component input
* @section read-only
* @react
import { Input } from '@collab-ui/react';

export default function InputReadonly() {
  return (
    <Input
      name='inputReadonly'
      label='Read Only Input'
      htmlId='inputReadonly'
      inputSize='small-5'
      value='Read Only Text'
      readOnly
    />
  );
}

**/

/**
* @component input
* @section help-text
* @react
import { Input } from '@collab-ui/react';

export default function InputHelpText() {
  return (
    <div className='row'>
      <Input
        name='inputHelpText'
        label='Help Text Input'
        htmlId='inputHelpText'
        inputSize='small-5'
        inputHelpText='Help Text'
      />
    </div>
  );
}

**/

/**
* @component input
* @section secondary-label
* @react
import { Input } from '@collab-ui/react';

export default function InputSecondary() {
  return (
    <Input
      name='inputSecondaryLabel'
      label='Input with Secondary Label'
      htmlId='inputSecondaryLabel'
      inputSize='small-5'
      secondaryLabel='Secondary Label'
    />
  );
}
**/

/**
* @component input
* @section nested
* @react
import { Input } from '@collab-ui/react';

export default function InputNested() {
  return (
    <div className='row' key={'input1'}>
      <Input
        name='inputParent'
        label='Parent Input Example'
        htmlId='inputParent'
        inputSize='small-5'
      />
    </div>,
    <div className='row' key={'input2'}>
      <Input
        name='inputNested1'
        label='Child Input Nested 1 Level'
        inputSize='small-5'
        htmlId='inputNested1'
        nestedLevel={1}
      />
    </div>,
    <div className='row' key={'input3'}>
      <Input
        name='inputNested2'
        label='Child Input Nested 2 Levels'
        inputSize='small-5'
        htmlId='inputNested2'
        nestedLevel={2}
      />
    </div>,
    <div className='row' key={'input4'}>
      <Input
        name='inputNested3'
        label='Child Input Nested 3 Levels'
        inputSize='small-5'
        htmlId='inputNested3'
        nestedLevel={3}
      />
    </div>
  );
}

**/