"use strict";

exports.__esModule = true;
exports.default = void 0;

var _react = _interopRequireDefault(require("react"));

var _propTypes = _interopRequireDefault(require("prop-types"));

var _get = _interopRequireDefault(require("lodash/get"));

var _ = require("./..");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

var ActivityButton = function ActivityButton(props) {
  var ariaLabel = props.ariaLabel,
      className = props.className,
      disabled = props.disabled,
      large = props.large,
      onClick = props.onClick,
      type = props.type,
      otherHTMLProps = _objectWithoutPropertiesLoose(props, ["ariaLabel", "className", "disabled", "large", "onClick", "type"]);

  return _react.default.createElement(_.Button, _extends({
    ariaLabel: ariaLabel || !type.icon && type || '',
    circle: true,
    className: 'cui-activity' + ("" + (!type.icon && " cui-activity__" + type || '')) + ("" + (className && " " + className || '')),
    color: (0, _get.default)(type, 'color'),
    disabled: disabled,
    onClick: onClick
  }, large ? {
    size: 84,
    containerLarge: true
  } : {
    size: 68
  }, otherHTMLProps), type.icon ? type.icon : _react.default.createElement(_.Icon, {
    name: "" + type + (large ? '_36' : '_28')
  }));
};

ActivityButton.displayName = 'ActivityButton';
ActivityButton.propTypes = {
  /** @prop Text to display for blindness accessibility features | '' */
  ariaLabel: _propTypes.default.string,

  /** @prop Optional css class string | '' */
  className: _propTypes.default.string,

  /** @prop Sets the attribute disabled to the button | false */
  disabled: _propTypes.default.bool,

  /** @prop Sets the large attribute to the button | false */
  large: _propTypes.default.bool,

  /** @prop Handler to be called when the user taps the button | null */
  onClick: _propTypes.default.func,

  /** @prop Sets the button's activity type */
  type: _propTypes.default.oneOfType([_propTypes.default.oneOf(['chat', 'camera', 'meetings', 'whiteboard', 'files', 'share-screen', 'tasks']), _propTypes.default.shape({
    color: _propTypes.default.string,
    icon: _propTypes.default.element.isRequired
  })]).isRequired
};
ActivityButton.defaultProps = {
  ariaLabel: '',
  className: '',
  disabled: false,
  large: false,
  onClick: null,
  type: ''
};
var _default = ActivityButton;
/**
* @component activity-button
* @section default
*
* @react
import { ActivityButton } from '@collab-ui/react';

export default function ActivityButtonDefault() {
  return(
      <div>
        <ActivityButton
          type='chat'
          ariaLabel='jlshjksfghjl'
          onClick={()=>{}}
          label='Chat'
        />
        <ActivityButton
          type='camera'
          onClick={()=>{}}
          label='Camera'
        />
        <ActivityButton
          type='meetings'
          onClick={()=>{}}
          label='Meetings'
        />
        <ActivityButton
          type='whiteboard'
          onClick={()=>{}}
          label='Whiteboard'
        />
        <ActivityButton
          type='files'
          onClick={()=>{}}
          label='Files'
        />
        <ActivityButton
          type='share-screen'
          onClick={()=>{}}
          label='Share'
        />
        <ActivityButton
          type='tasks'
          onClick={()=>{}}
          label='Tasks'
        />
      </div>
  );
}

**/

/**
* @component activity-button
* @section large
*
* @react
import { ActivityButton } from '@collab-ui/react';

export default function ActivityButtonLarge() {
  return(
      <div>
        <ActivityButton
          type='chat'
          large
          onClick={()=>{}}
          label='Chat'
          ariaLabel='Chat'
        />
        <ActivityButton
          type='camera'
          large
          onClick={()=>{}}
          label='Camera'
          ariaLabel='Camera'
        />
        <ActivityButton
          type='meetings'
          large
          onClick={()=>{}}
          label='Meetings'
          ariaLabel='Meetings'
        />
        <ActivityButton
          type='whiteboard'
          large
          onClick={()=>{}}
          label='Whiteboard'
          ariaLabel='Whiteboard'
        />
        <ActivityButton
          type='files'
          large
          onClick={()=>{}}
          label='Files'
          ariaLabel='Files'
        />
        <ActivityButton
          type='share-screen'
          large
          onClick={()=>{}}
          label='Share'
          ariaLabel='Share'
        />
        <ActivityButton
          type='tasks'
          large
          onClick={()=>{}}
          label='Tasks'
          ariaLabel='Tasks'
          title='tasks'
        />
      </div>
  );
}

**/

/**
* @component activityButton
* @section custom
*
* @react
import { ActivityButton } from '@collab-ui/react';

export default function ActivityButtonCustom() {
  return(
    <div>
      <ActivityButton
        type={{
          color: 'mint',
          icon: <span className='icon icon-arrow-left_32'/>
        }}
        large
        onClick={()=>{}}
        ariaLabel='Left Arrow'
      />
      <ActivityButton
        type={{
          color: 'red',
          icon: <span className='icon icon-keyboard_16'/>
        }}
        onClick={()=>{}}
        ariaLabel='Keyboard'
      />
    </div>
  );
}

**/

exports.default = _default;