"use strict";

exports.__esModule = true;
exports.default = void 0;

var _react = _interopRequireDefault(require("react"));

var _propTypes = _interopRequireDefault(require("prop-types"));

var _ = require("./..");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/** @component chip */
var Chip = function Chip(_ref) {
  var className = _ref.className,
      leftContent = _ref.leftContent,
      fileDownloadLink = _ref.fileDownloadLink,
      fileType = _ref.fileType,
      rightContent = _ref.rightContent,
      subTitle = _ref.subTitle,
      title = _ref.title,
      type = _ref.type;
  Chip.displayName = 'Chip'; // This appears to be a false positive
  // See: https://github.com/yannickcr/eslint-plugin-react/issues/1181
  // eslint-disable-next-line react/no-multi-comp

  function buildChipLeft() {
    if (type === 'file') {
      return _react.default.createElement(_.Icon, {
        name: "file-" + fileType + "_32"
      });
    }

    if (type === 'recording') {
      return _react.default.createElement(_.Icon, {
        name: "play-circle_32",
        color: "white"
      });
    }

    if (type === 'unauthorized') {
      return _react.default.createElement(_.Icon, {
        name: "warning_32"
      });
    }

    return leftContent;
  } // eslint-disable-next-line react/no-multi-comp


  function buildChipRight() {
    if (rightContent) {
      return rightContent;
    }

    if (type === 'file' && fileDownloadLink) {
      return _react.default.createElement("a", {
        className: "file-download",
        download: true,
        href: fileDownloadLink
      }, _react.default.createElement("i", {
        className: "icon icon-download_32"
      }));
    }

    return null;
  }

  var chipLeft = buildChipLeft();
  var chipRight = buildChipRight();
  return _react.default.createElement("div", {
    className: 'cui-chip' + ("" + (className && " " + className || ''))
  }, _react.default.createElement("div", {
    className: 'cui-chip-left' + ("" + (type && " " + type || ''))
  }, chipLeft), _react.default.createElement("div", {
    className: "cui-chip-center"
  }, title && _react.default.createElement("div", {
    className: "cui-chip__title lead"
  }, title), subTitle && _react.default.createElement("div", {
    className: "cui-chip__sub-title subheader"
  }, subTitle)), chipRight && _react.default.createElement("div", {
    className: "cui-chip-right"
  }, chipRight));
};

Chip.propTypes = {
  /** @prop Optional css class string | '' */
  className: _propTypes.default.string,

  /** @prop Sets file for anchor element to download | '' */
  fileDownloadLink: _propTypes.default.string,

  /** @prop Sets type of file | null */
  fileType: _propTypes.default.oneOf(['audio', 'graph', 'image', 'locked', 'missing', 'pdf', 'spreadsheet', 'text', 'video', 'zip']),

  /** @prop Node that becomes the content on the left of Chip | null */
  leftContent: _propTypes.default.node,

  /** @prop NOde that becomes the content on the right of Chip | null */
  rightContent: _propTypes.default.node,

  /** @prop Text of the Chip's subtitle | '' */
  subTitle: _propTypes.default.string,

  /** @prop Text of the Chip's title | null */
  title: _propTypes.default.string,

  /** @prop Sets the type of icon for the Chip | null */
  type: _propTypes.default.oneOf(['file', 'recording', 'unauthorized'])
};
Chip.defaultProps = {
  className: '',
  fileDownloadLink: '',
  fileType: null,
  leftContent: null,
  rightContent: null,
  subTitle: '',
  title: null,
  type: null
};
var _default = Chip;
/**
 * @component chip
 * @section recording
 * @react
 import { Chip } from '@collab-ui/react';

 export default function ChipDefault() {
   return (
      <Chip
        type="unauthorized"
        title="Webex Teams Recording"
        subTitle="18 min"
      />
   );
 }

 **/

/**
 * @component chip
 * @section recording
 * @react
 import { Chip } from '@collab-ui/react';

 export default function ChipRecording() {
   return (
      <Chip
        type="recording"
        title="Webex Teams Recording"
        subTitle="18 min"
      />
   );
 }

 **/

/**
 * @component chip
 * @section file
 * @react
 import { Chip } from '@collab-ui/react';

 export default function ChipFile() {
   return (
      <Chip
        type="file"
        fileType="audio"
        title="Filename.mp3"
        subTitle="23kb"
        fileDownloadLink="https://www.google.com"
      />
   );
 }
 **/

exports.default = _default;