"use strict";

exports.__esModule = true;
exports.default = void 0;

var _react = _interopRequireDefault(require("react"));

var _propTypes = _interopRequireDefault(require("prop-types"));

var _omit = _interopRequireDefault(require("lodash/omit"));

var _uniqueId = _interopRequireDefault(require("lodash/uniqueId"));

var _querySelectorAll = _interopRequireDefault(require("dom-helpers/query/querySelectorAll"));

var _reactUid = require("react-uid");

var _SelectableContext = _interopRequireDefault(require("../SelectableContext"));

var _ListContext = _interopRequireDefault(require("../ListContext"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _inheritsLoose(subClass, superClass) { subClass.prototype = Object.create(superClass.prototype); subClass.prototype.constructor = subClass; subClass.__proto__ = superClass; }

var List =
/*#__PURE__*/
function (_React$Component) {
  _inheritsLoose(List, _React$Component);

  List.getDerivedStateFromProps = function getDerivedStateFromProps(_ref, state) {
    var active = _ref.active;
    return active ? _extends({}, state, {
      listContext: _extends({}, state.listContext, {
        active: active
      })
    }) : state;
  };

  function List(props) {
    var _this;

    _this = _React$Component.call(this, props) || this;

    _this.determineInitialFocus = function () {
      var items = (0, _querySelectorAll.default)(_this.listNode, ".cui-list-item:not(.disabled):not(:disabled):not(.cui-list-item--read-only)");
      _this._needsRefocus = true;
      items.length && _this.getNextFocusedChild(items[0], 0);
    };

    _this.getIncludesFirstCharacter = function (str, char) {
      return str.charAt(0).toLowerCase().includes(char);
    };

    _this.handleKeyDown = function (e) {
      var focus = _this.state.listContext.focus;
      var clickEvent;
      var tgt = e.currentTarget;
      var char = e.key;
      var items = (0, _querySelectorAll.default)(_this.listNode, ".cui-list-item:not(.disabled):not(:disabled):not(.cui-list-item--read-only)");
      var length = items.length && items.length - 1 || 0;
      var focusIdx = focus && items.indexOf(_this.listNode.querySelector("[data-md-event-key=" + focus + "]")) || 0;
      var flag = false;

      var isPrintableCharacter = function isPrintableCharacter(str) {
        return str.length === 1 && str.match(/\S/);
      };

      switch (e.which) {
        case 32:
        case 13:
          try {
            clickEvent = new MouseEvent('click', {
              view: window,
              bubbles: true,
              cancelable: true
            });
          } catch (err) {
            if (document.createEvent) {
              // DOM Level 3 for IE 9+
              clickEvent = document.createEvent('MouseEvents');
              clickEvent.initEvent('click', true, true);
            }
          }

          tgt.dispatchEvent(clickEvent);
          flag = true;
          break;

        case 38:
        case 37:
          _this.getNextFocusedChild(tgt, -1);

          _this._needsRefocus = true;
          flag = true;
          break;

        case 39:
        case 40:
          _this.getNextFocusedChild(tgt, 1);

          _this._needsRefocus = true;
          flag = true;
          break;

        case 33:
        case 36:
          _this.setFocusToLimit('start', items, length);

          _this._needsRefocus = true;
          flag = true;
          break;

        case 34:
        case 35:
          _this.setFocusToLimit('end', items, length);

          _this._needsRefocus = true;
          flag = true;
          break;

        default:
          if (isPrintableCharacter(char)) {
            _this.setFocusByFirstCharacter(char, focusIdx, items, length);

            _this._needsRefocus = true;
            flag = true;
          }

          break;
      }

      if (flag) {
        e.stopPropagation();
        e.preventDefault();
      }
    };

    _this.handleSelect = function (e, opts) {
      var onSelect = _this.props.onSelect;
      var active = _this.state.listContext.active;
      var eventKey = opts.eventKey,
          label = opts.label,
          value = opts.value;
      var items = (0, _querySelectorAll.default)(_this.listNode, '.cui-list-item');
      var index = items.indexOf(_this.listNode.querySelector("[data-md-event-key=" + eventKey + "]"));

      _this.setFocus(index); // Don't do anything if onSelect Event Handler is present


      if (onSelect) {
        return onSelect(e, {
          eventKey: items[index].attributes['data-md-event-key'].value,
          label: label,
          value: value
        });
      } // Don't do anything if index is the same or outside of the bounds


      if (eventKey === active || index < 0 || index >= items.length - 1) return; // Keep reference to last index for event handler

      var last = active; // Call change event handler

      _this.setState(function (state) {
        return {
          last: last,
          listContext: _extends({}, state.listContext, {
            active: items[index].attributes['data-md-event-key'].value
          })
        };
      });
    };

    _this.setFocus = function (index) {
      var items = (0, _querySelectorAll.default)(_this.listNode, '.cui-list-item');

      _this.setState(function (state) {
        return {
          listContext: _extends({}, state.listContext, {
            focus: items[index].attributes['data-md-event-key'].value
          })
        };
      });
    };

    _this.setFocusByFirstCharacter = function (char, focusIdx, items, length) {
      var newIndex = items.reduce(function (agg, item, idx, arr) {
        var index = focusIdx + idx + 1 > length ? Math.abs(focusIdx + idx - length) : focusIdx + idx + 1;
        return !agg.length && arr[index].attributes['data-md-keyboard-key'] && arr[index].attributes['data-md-keyboard-key'].value && _this.getIncludesFirstCharacter(arr[index].attributes['data-md-keyboard-key'].value, char) ? agg.concat(arr[index].attributes['data-md-event-key'].value) : agg;
      }, []);
      typeof newIndex[0] === 'string' && _this.setState(function (state) {
        return {
          listContext: _extends({}, state.listContext, {
            focus: newIndex[0]
          })
        };
      });
    };

    _this.state = {
      id: props.id || (0, _uniqueId.default)('cui-list-'),
      last: 0,
      listContext: {
        active: props.active,
        focus: null,
        role: props.itemRole,
        type: props.type
      },
      selectContext: {
        parentKeyDown: _this.handleKeyDown,
        parentOnSelect: _this.handleSelect
      }
    };
    return _this;
  }

  var _proto = List.prototype;

  _proto.componentDidMount = function componentDidMount() {
    var focusFirst = this.props.focusFirst;
    focusFirst && this.listNode && this.determineInitialFocus();
  };

  _proto.componentDidUpdate = function componentDidUpdate(prevProps, prevState) {
    var listContext = this.state.listContext;
    if (!this._needsRefocus || !this.listNode) return;

    if (listContext.focus && prevState.listContext.focus !== listContext.focus) {
      this.listNode.querySelector("[data-md-event-key=" + listContext.focus + "]").focus();
    }
  };

  _proto.getNextFocusedChild = function getNextFocusedChild(current, offset) {
    if (!this.listNode) return null;
    var items = (0, _querySelectorAll.default)(this.listNode, ".cui-list-item:not(.disabled):not(:disabled):not(.cui-list-item--read-only)");
    var possibleIndex = items.indexOf(current) + offset;

    var getIndex = function getIndex() {
      if (possibleIndex < 0) {
        return items.length - 1;
      } else if (possibleIndex > items.length - 1) {
        return 0;
      } else return possibleIndex;
    };

    this.setState({
      listContext: _extends({}, this.state.listContext, {
        focus: items[getIndex()].attributes['data-md-event-key'].value
      })
    });
  };

  _proto.setFocusToLimit = function setFocusToLimit(target, items, length) {
    var focus = this.state.listContext.focus;
    var newFocusKey = items[target === 'start' ? 0 : length].attributes['data-md-event-key'].value;
    newFocusKey !== focus && this.setState({
      listContext: _extends({}, this.state.listContext, {
        focus: newFocusKey
      })
    });
  };

  _proto.render = function render() {
    var _this2 = this;

    var _this$props = this.props,
        active = _this$props.active,
        children = _this$props.children,
        className = _this$props.className,
        role = _this$props.role,
        tabType = _this$props.tabType,
        wrap = _this$props.wrap,
        props = _objectWithoutPropertiesLoose(_this$props, ["active", "children", "className", "role", "tabType", "wrap"]);

    var _this$state = this.state,
        listContext = _this$state.listContext,
        selectContext = _this$state.selectContext;
    var otherProps = (0, _omit.default)(_extends({}, props), ['focusFirst', 'itemRole', 'type']);

    var getActiveId = function getActiveId() {
      var activeNode = active && active.length && _this2.listNode && _this2.listNode.querySelector("[data-md-event-key=" + active[0] + "]");

      return activeNode && activeNode.id;
    };
    /* eslint-disable jsx-a11y/aria-activedescendant-has-tabindex */


    return _react.default.createElement(_SelectableContext.default.Provider, {
      value: selectContext
    }, _react.default.createElement(_ListContext.default.Provider, {
      value: listContext
    }, _react.default.createElement("div", _extends({
      className: 'cui-list' + ("" + (tabType && " cui-list--" + tabType || '')) + ("" + (wrap && " cui-list--wrap" || '')) + ("" + (className && " " + className || '')),
      role: role,
      "aria-activedescendant": getActiveId(),
      ref: function ref(_ref2) {
        return _this2.listNode = _ref2;
      }
    }, otherProps), _react.default.createElement(_reactUid.UIDReset, null, children))));
    /* eslint-enable*/
  };

  return List;
}(_react.default.Component);

List.propTypes = {
  /** @prop Optional active prop to pass active prop to children | null */
  active: _propTypes.default.oneOfType([_propTypes.default.string, _propTypes.default.array, _propTypes.default.number]),

  /** @prop Children nodes to render inside List | null */
  children: _propTypes.default.node,

  /** @prop Optional css class string | '' */
  className: _propTypes.default.string,

  /** @prop Sets first List item to have focus | true */
  focusFirst: _propTypes.default.bool,

  /** @prop Optional ID value of List | null */
  id: _propTypes.default.string,

  /** @prop Optional tabType prop type to manually set child role | 'listitem' */
  itemRole: _propTypes.default.string,

  /** @prop Callback function invoked by user selecting an interactive item within List | null */
  onSelect: _propTypes.default.func,

  /** @prop Sets the ARIA role for the Nav, in the context of a TabContainer | 'list' */
  role: _propTypes.default.string,

  /** @prop Sets the orientation of the List | 'vertical' */
  tabType: _propTypes.default.oneOf(['vertical', 'horizontal']),

  /** @prop Sets List size | null */
  type: _propTypes.default.oneOf(['small', 'large', 'space', 'xlarge']),

  /** @prop Optional wrap prop type to wrap items to next row */
  wrap: _propTypes.default.bool
};
List.defaultProps = {
  active: null,
  children: null,
  className: '',
  id: null,
  itemRole: 'listitem',
  focusFirst: true,
  onSelect: null,
  role: 'list',
  tabType: 'vertical',
  type: null,
  wrap: false
};
List.displayName = 'List';
var _default = List;
exports.default = _default;